package com.gic.haoban.manage.web.controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import cn.hutool.core.collection.CollectionUtil;

import com.gic.clerk.api.dto.ClerkDTO;
import com.gic.clerk.api.service.ClerkService;
import com.gic.commons.util.EntityUtil;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.dto.StaffDepartmentRelatedDTO;
import com.gic.haoban.manage.api.service.StaffDepartmentRelatedApiService;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.vo.ClerkVo;

@RestController
public class ClerkController extends WebBaseController{
	@Autowired
	private ClerkService clerkService;
	@Autowired
	private StaffDepartmentRelatedApiService staffDepartmentRelatedApiService;
	//导购列表
	@RequestMapping("/clerk-list")
	public HaobanResponse clerkList(String storeId,String bindFlag,String departmentId) {
		List<StaffDepartmentRelatedDTO> list = staffDepartmentRelatedApiService.listByDepartmentId(departmentId);
		List<ClerkVo> result  = new ArrayList<ClerkVo>();
		//绑定的clerk
		if("1".equals(bindFlag)){
			// 调陶接口获取详情数据
			if(CollectionUtil.isNotEmpty(list)){
				List<String> clerkCodes = list.stream().filter(s->s.getClerkCode()!=null).map(s->s.getClerkCode()).collect(Collectors.toList());
				if(CollectionUtil.isNotEmpty(clerkCodes)){
					List<ClerkDTO> clerkList = clerkService.listClerk(storeId, clerkCodes, true);
					result = EntityUtil.changeEntityListByJSON(ClerkVo.class, clerkList);
				}
			}
		}else{
			//未绑定的clerk
			// 调陶接口获取详情数据
			if(CollectionUtil.isNotEmpty(list)){
				List<String> clerkCodes = list.stream().filter(s->s.getClerkCode()!=null).map(s->s.getClerkCode()).collect(Collectors.toList());
				if(CollectionUtil.isNotEmpty(clerkCodes)){
					List<ClerkDTO> clerkList = clerkService.listClerk(storeId, clerkCodes, false);
					result = EntityUtil.changeEntityListByJSON(ClerkVo.class, clerkList);
				}
			}else{
				List<String> clerkCodes = new ArrayList();
				clerkCodes.add("xxxXXXX");
				List<ClerkDTO> clerkList = clerkService.listClerk(storeId, clerkCodes, false);
				result = EntityUtil.changeEntityListByJSON(ClerkVo.class, clerkList);
			}
		}
		return resultResponse(HaoBanErrCode.ERR_1,result);
		
	}
	//成员绑定
	@RequestMapping("/staff-bind")
	public HaobanResponse staffBind(String clerkCode,String staffDepartmentRelatedId) {
		StaffDepartmentRelatedDTO dto = new StaffDepartmentRelatedDTO();
		dto.setStaffDepartmentRelatedId(staffDepartmentRelatedId);
		dto.setClerkCode(clerkCode);
		dto.setUpdateTime(new Date());
		staffDepartmentRelatedApiService.updateById(dto);
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	//成员换绑定
	@RequestMapping("/clerk-unbind")
	public HaobanResponse clerkUnbind(String clerkCode,String staffDepartmentRelatedId) {
		StaffDepartmentRelatedDTO one = staffDepartmentRelatedApiService.getOneByClerkCode(clerkCode);
		if(one != null){
			//存在，则先置空
			one.setClerkCode(null);
			one.setUpdateTime(new Date());
			staffDepartmentRelatedApiService.deleteCode(one);
		}
		//不存在，则更新
		StaffDepartmentRelatedDTO dto = new StaffDepartmentRelatedDTO();
		dto.setStaffDepartmentRelatedId(staffDepartmentRelatedId);
		dto.setClerkCode(clerkCode);
		dto.setUpdateTime(new Date());
		staffDepartmentRelatedApiService.updateById(dto);
		return resultResponse(HaoBanErrCode.ERR_1);
	}

}
