package com.gic.haoban.manage.web.controller;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.gic.api.base.commons.Page;
import com.gic.haoban.base.api.common.BasePageInfo;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.dto.DepartmentDTO;
import com.gic.haoban.manage.api.dto.StaffDTO;
import com.gic.haoban.manage.api.dto.StaffDepartmentRelatedDTO;
import com.gic.haoban.manage.api.service.DepartmentApiService;
import com.gic.haoban.manage.api.service.StaffApiService;
import com.gic.haoban.manage.web.auth.AuthRequestUtil;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.vo.LoginVO;

@RestController
public class StaffController extends WebBaseController{
	
	@Autowired
	private StaffApiService staffApiService;
	@Autowired
	private DepartmentApiService departmentApiService;
	
	@RequestMapping("staff-add")
	public HaobanResponse staffAdd(StaffDTO staffDTO,String departmentIds){
		LoginVO login = (LoginVO) AuthRequestUtil.getAppLoginUser();
		String wxEnterpriseId = login.getWxEnterpriseId();
		String staffName = staffDTO.getStaffName();
		String phoneNumber = staffDTO.getPhoneNumber();
		String nationcode = staffDTO.getNationCode();
		if(StringUtils.isBlank(staffName)) {
			return resultResponse(HaoBanErrCode.ERR_10004);
		}
		StaffDTO staff = staffApiService.selectByNationcodeAndPhoneNumber(wxEnterpriseId,nationcode,phoneNumber);
		if(staff != null) {
			return resultResponse(HaoBanErrCode.ERR_10005);
		}
		HaobanResponse hr = staffApiService.add(staff,departmentIds);
		
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	
	@RequestMapping("staff-sel")
	public HaobanResponse staffSel(String staffId,String staffDepartmentRelatedId){
		StaffDTO staff = staffApiService.selectById(staffId);
		List<StaffDepartmentRelatedDTO> list = staffApiService.listStaffDepartmentByStaffId(staffId);
		List<DepartmentDTO> departmentList = new ArrayList<DepartmentDTO>();
		for (StaffDepartmentRelatedDTO staffDepartmentRelatedDTO : list) {
			DepartmentDTO dto = departmentApiService.selectById(staffDepartmentRelatedDTO.getDepartmentId());
			departmentList.add(dto);
			
		}
		staff.setDepartmentList(departmentList);
		return resultResponse(HaoBanErrCode.ERR_1,staff);
	}
	
	@RequestMapping("staff-list")
	public HaobanResponse staffList(String departmentId,Integer activeFlag,String keyword,BasePageInfo pageInfo){
		Page<StaffDTO> page = staffApiService.pageStaff(departmentId,activeFlag,keyword,pageInfo);
		return resultResponse(HaoBanErrCode.ERR_1,page);
	}
	
	@RequestMapping("staff-del")
	public HaobanResponse staffDel(String staffDepartmentStaffRelatedId){
		staffApiService.del(staffDepartmentStaffRelatedId);
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	
	@RequestMapping("staff-batch-del")
	public HaobanResponse staffBatchDel(String staffDepartmentStaffRelatedIds){
		String[] staffArr = staffDepartmentStaffRelatedIds.split(",");
		for (String string : staffArr) {
			staffApiService.del(string);
		}
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	
	@RequestMapping("staff-edit")
	public HaobanResponse staffEdit(StaffDTO staffDTO,String departmentIds){
		String staffId = staffDTO.getStaffId();
		
		staffApiService.staffEdit(staffDTO,departmentIds);
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	
	

}
