package com.gic.haoban.manage.web.controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import cn.hutool.core.collection.CollectionUtil;

import com.gic.clerk.api.dto.ClerkDTO;
import com.gic.clerk.api.service.ClerkService;
import com.gic.commons.util.EntityUtil;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.manage.api.dto.StaffDTO;
import com.gic.haoban.manage.api.dto.StaffDepartmentRelatedDTO;
import com.gic.haoban.manage.api.service.StaffApiService;
import com.gic.haoban.manage.api.service.StaffDepartmentRelatedApiService;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.interceptor.WebInterceptor;
import com.gic.haoban.manage.web.vo.ClerkVo;
import com.gic.haoban.manage.web.vo.StoreVO;

@RestController
public class ClerkController extends WebBaseController{
    private static Logger logger= LoggerFactory.getLogger(WebInterceptor.class);

	@Autowired
	private ClerkService clerkService;
	@Autowired
	private StaffApiService staffApiService;
	@Autowired
	private StaffDepartmentRelatedApiService staffDepartmentRelatedApiService;

	//导购列表
	@RequestMapping("/clerk-list")
	public HaobanResponse clerkList(String storeId,String bindFlag,String departmentId) {
		List<StaffDepartmentRelatedDTO> list = staffDepartmentRelatedApiService.listByDepartmentId(departmentId);
		List<ClerkVo> result  = new ArrayList<ClerkVo>();
//		if(CollectionUtil.isNotEmpty(list)){
//			if("1".equals(bindFlag)){
//				List<StaffDepartmentRelatedDTO> bindList = list.stream().filter(s->s.getClerkCode() != null).collect(Collectors.toList());
//				if(CollectionUtil.isNotEmpty(bindList)){
//					result = EntityUtil.changeEntityListByJSON(ClerkVo.class, bindList);
//				}
//			}else{
//
//				List<StaffDepartmentRelatedDTO> unBindList = list.stream().filter(s->s.getClerkCode() == null).collect(Collectors.toList());
//				if(CollectionUtil.isNotEmpty(unBindList)){
//					result = EntityUtil.changeEntityListByJSON(ClerkVo.class, unBindList);
//				}
//			}
//		}
//		return resultResponse(HaoBanErrCode.ERR_1,result);
		if(StringUtils.isAnyBlank(storeId,bindFlag,departmentId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		//绑定的clerk
		if("1".equals(bindFlag)){
			// 调陶接口获取详情数据
			if(CollectionUtil.isNotEmpty(list)){
				List<String> clerkCodes = list.stream().filter(s->s.getClerkCode()!=null).map(s->s.getClerkCode()).collect(Collectors.toList());
				if(CollectionUtil.isNotEmpty(clerkCodes)){
					List<ClerkDTO> clerkList = clerkService.listClerk(storeId, clerkCodes, true);
					result = EntityUtil.changeEntityListByJSON(ClerkVo.class, clerkList);
				}
			}
		}else{
			//未绑定的clerk
			// 调陶接口获取详情数据
			if(CollectionUtil.isNotEmpty(list)){
				List<String> clerkCodes = list.stream().filter(s->s.getClerkCode()!=null).map(s->s.getClerkCode()).collect(Collectors.toList());
				if(CollectionUtil.isNotEmpty(clerkCodes)){
					List<ClerkDTO> clerkList = clerkService.listClerk(storeId, clerkCodes, false);
					result = EntityUtil.changeEntityListByJSON(ClerkVo.class, clerkList);
				}
			}else{
				List<String> clerkCodes = new ArrayList();
				clerkCodes.add("xxxXXXX");
				List<ClerkDTO> clerkList = clerkService.listClerk(storeId, clerkCodes, false);
				result = EntityUtil.changeEntityListByJSON(ClerkVo.class, clerkList);
			}
		}
		return resultResponse(HaoBanErrCode.ERR_1,result);
		
	}
	//选择成员列表
	@RequestMapping("/staff-list")
	public HaobanResponse staffList(String departmentId) {
		boolean b = StringUtils.isAnyBlank(departmentId);
		logger.info("b===========================>{}",b);
		if(StringUtils.isAnyBlank(departmentId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		List<StaffDepartmentRelatedDTO> list = staffDepartmentRelatedApiService.listByDepartmentId(departmentId);
		Map<String,StaffDepartmentRelatedDTO> relatedMap = com.gic.commons.util.CollectionUtil.toMap(list, "staffId");
		List<String> staffIds = list.stream().map(s->s.getStaffId()).collect(Collectors.toList());
		List<StaffDTO>  resultlist= staffApiService.listByIds(staffIds);
		for(StaffDTO dto :resultlist){
			if(relatedMap.get(dto.getStaffId()) != null){
				dto.setStaffDepartmentRelatedId(relatedMap.get(dto.getStaffId()).getStaffDepartmentRelatedId());
				if(relatedMap.get(dto.getStaffId()).getClerkCode()!=null){
					dto.setBindFlag(1);
					dto.setClerkCode(relatedMap.get(dto.getStaffId()).getClerkCode());
				}else{
					dto.setBindFlag(0);
				}
			}else{
				dto.setBindFlag(0);
			}
		}
		return resultResponse(HaoBanErrCode.ERR_1,resultlist);
		
	}
	//成员绑定
	@RequestMapping("/staff-bind")
	public HaobanResponse staffBind(String toClerkCode,String staffDepartmentRelatedId) {
		if(StringUtils.isAnyBlank(toClerkCode,staffDepartmentRelatedId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		//将指定人绑定clerkCode
		StaffDepartmentRelatedDTO dto = new StaffDepartmentRelatedDTO();
		dto.setStaffDepartmentRelatedId(staffDepartmentRelatedId);
		dto.setClerkCode(toClerkCode);
		dto.setUpdateTime(new Date());
		staffDepartmentRelatedApiService.updateById(dto);
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	//成员解除绑定
	@RequestMapping("/clerk-single-unbind")
	public HaobanResponse clerkSingleUnbind(String clerkCode) {
		if(StringUtils.isAnyBlank(clerkCode)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		//将自己的clerkCode置空
		StaffDepartmentRelatedDTO one = staffDepartmentRelatedApiService.getOneByClerkCode(clerkCode);
		if(one != null){
			//存在，则先置空
			one.setClerkCode(null);
			one.setUpdateTime(new Date());
			staffDepartmentRelatedApiService.deleteCode(one);
		}
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	//成员换绑定
	@RequestMapping("/clerk-unbind")
	public HaobanResponse clerkUnbind(String fromClerkCode,String toClerkCode) {
		if(StringUtils.isAnyBlank(fromClerkCode,toClerkCode)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		//将别人clerkCode置空
		StaffDepartmentRelatedDTO one = staffDepartmentRelatedApiService.getOneByClerkCode(toClerkCode);
		if(one != null){
			//存在，则先置空
			one.setClerkCode(null);
			one.setUpdateTime(new Date());
			staffDepartmentRelatedApiService.deleteCode(one);
		}
		//将别人的clerkCode换到自己上面
		StaffDepartmentRelatedDTO two = staffDepartmentRelatedApiService.getOneByClerkCode(fromClerkCode);
		if(two != null){
			//存在，则先置空
			two.setClerkCode(toClerkCode);
			two.setClerkCode(toClerkCode);
			two.setUpdateTime(new Date());
			staffDepartmentRelatedApiService.updateById(two);
		}
		return resultResponse(HaoBanErrCode.ERR_1);
	}
	//店长转让
	@RequestMapping("/clerk-manager-tranfer")
	public HaobanResponse clerkManagerTranfer(String clerkCode,String storeId,String staffDepartmentRelatedId) {
		if(StringUtils.isAnyBlank(clerkCode,storeId,staffDepartmentRelatedId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		StaffDepartmentRelatedDTO one = staffDepartmentRelatedApiService.getOneByClerkCode(clerkCode);
		if(one != null){
			//存在，则先置空
			one.setClerkCode(null);
			one.setUpdateTime(new Date());
			staffDepartmentRelatedApiService.deleteCode(one);
		}
		//将其他人更新为店长
		StaffDepartmentRelatedDTO dto = new StaffDepartmentRelatedDTO();
		dto.setStaffDepartmentRelatedId(staffDepartmentRelatedId);
		dto.setClerkCode(clerkCode);
		dto.setUpdateTime(new Date());
		staffDepartmentRelatedApiService.updateById(dto);
		
		return resultResponse(HaoBanErrCode.ERR_1);
	}
}
