package com.gic.haoban.manage.web.controller;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateUtil;

import com.gic.clerk.api.dto.ClerkDTO;
import com.gic.clerk.api.service.ClerkService;
import com.gic.commons.util.EntityUtil;
import com.gic.enterprise.api.dto.StoreDTO;
import com.gic.enterprise.api.service.StoreService;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.data.api.dto.HaobanDataDTO;
import com.gic.haoban.data.api.service.HaobanDataApiService;
import com.gic.haoban.manage.api.dto.DepartmentDTO;
import com.gic.haoban.manage.api.dto.StaffDTO;
import com.gic.haoban.manage.api.dto.StaffDepartmentRelatedDTO;
import com.gic.haoban.manage.api.service.DepartmentApiService;
import com.gic.haoban.manage.api.service.StaffApiService;
import com.gic.haoban.manage.api.service.StaffDepartmentRelatedApiService;
import com.gic.haoban.manage.api.service.WxEnterpriseRelatedApiService;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.vo.ClerkVo;
import com.gic.haoban.manage.web.vo.StoreVO;

@RestController
public class StoreController extends WebBaseController{
	@Autowired
	private ClerkService clerkService;
	@Autowired
	private StaffApiService staffApiService;
	@Autowired
	private DepartmentApiService departmentApiService;
	@Autowired
	private StaffDepartmentRelatedApiService staffDepartmentRelatedApiService;
	@Autowired
	private WxEnterpriseRelatedApiService wxEnterpriseRelatedApiService;
	@Autowired
	private HaobanDataApiService haobanDataApiService;
	@Autowired
	private StoreService storeService;
	//门店列表
	@RequestMapping("/store-list")
	public HaobanResponse storeList(String staffId,String wxEnterpriseId) {
		if(StringUtils.isAnyBlank(staffId,wxEnterpriseId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		List<DepartmentDTO> list = departmentApiService.listStoreByWxEnterpriseId(wxEnterpriseId);
		if(CollectionUtil.isEmpty(list)){
			return resultResponse(HaoBanErrCode.ERR_1);
		}
		//1、初始化Department表数据
		List<StoreVO> resultList = new ArrayList<StoreVO>();
		for(DepartmentDTO dto : list){
			StoreVO VO = new StoreVO();
			VO.setDepartmentId(dto.getDepartmentId());
			VO.setStoreId(dto.getRelatedId());//为空，则无该值
			VO.setStoreName(dto.getDepartmentName());
			VO.setWxEnterpriseId(dto.getWxEnterpriseId());
			VO.setStoreImg("");//先置空
			resultList.add(VO);
		}
		//2、获取关联表数据
		List<StaffDepartmentRelatedDTO> relateList = staffDepartmentRelatedApiService.listByStaffId(staffId);
		if(CollectionUtil.isNotEmpty(relateList)){
			Map<String,StaffDepartmentRelatedDTO> map = com.gic.commons.util.CollectionUtil.toMap(relateList, "departmentId");
			for(StoreVO VO : resultList){
				StaffDepartmentRelatedDTO staffDepartmentRelatedDTO = map.get(VO.getDepartmentId());
				if(staffDepartmentRelatedDTO != null){
					VO.setBindFlag(1);
					VO.setClerkCode(staffDepartmentRelatedDTO.getClerkCode());
					VO.setStaffDepartmentRelatedId(staffDepartmentRelatedDTO.getStaffDepartmentRelatedId());
					VO.setStaffId(staffId);
				}else{
					VO.setBindFlag(0);
				}
			}
		}
		//3、判断是否是店长
		for(StoreVO VO : resultList){
			//已经绑定的门店
			if(VO.getBindFlag()==1){
				String clerkCode = VO.getClerkCode();
				if(StringUtils.isEmpty(clerkCode)){
					VO.setClerkType(0);
				}else{
					//查gic门店
					StoreDTO storeDTO = storeService.getStore(VO.getStoreId());
					if(storeDTO != null){
						//查gic门店店长
						ClerkDTO clerkDTO = clerkService.getClerkByClerkId(storeDTO.getClerkId());
						if(clerkDTO != null){
							//code相同，则置为1
							if(clerkCode.equals(clerkDTO.getClerkCode())){
								VO.setClerkType(1);
							}
						}
					}
				}
			}
		}
		return resultResponse(HaoBanErrCode.ERR_1,resultList);
	}
	//获取首页销售数据
	@RequestMapping("/sale-date")
	public HaobanResponse saleDate(String storeId) {
		if(StringUtils.isAnyBlank(storeId)){
			return resultResponse(HaoBanErrCode.ERR_2);
		}
		StoreDTO store = storeService.getStore(storeId);
		String enterpriseId = store.getEnterpriseId();
		String date = DateUtil.format(new Date(), "yyyy-MM-dd");
		HaobanDataDTO HaobanDataDTO = haobanDataApiService.getSaleDataByDate(enterpriseId, storeId, date);
		return resultResponse(HaoBanErrCode.ERR_1,HaobanDataDTO);
	}
}
